@@ -46,7 +46,9 @@ AboutDialog::AboutDialog(QWidget *parent)
 	tabWidget->addTab( new QLabel(
 				"<p><b>" + tr("Main developers") + "</b><br>"
 				"Bjrn Erik Nilsen &lt;bjoern.nilsen@bjoernen.com&gt;<br>" 
-				"Fredrik Berg Kjlstad &lt;fredrikbk@hotmail.com&gt;<br></p>"),
+				"Fredrik Berg Kjlstad &lt;fredrikbk@hotmail.com&gt;<br>"
+				"<p><b>" + tr("Contributors") + "</b><br>"
+				"Eric Stolten &lt;stoltene2@gmail.com&gt;<br></p>"),
 				tr("A&uthors"));
 	
 	QTextEdit *qte = new QTextEdit;
